<?php
/**
 * @file
 * Menu related theme functions.
 */


/**
 * Overrides theme_menu_local_tasks().
 */
function strapped_menu_local_tasks(&$variables) {
  $output = '';

  if (!empty($variables['primary'])) {
    $variables['primary']['#prefix'] = '<div class="element-invisible">' . t('Primary tabs') . '</div>';
    $variables['primary']['#prefix'] .= '<ul class="tabs--primary nav nav-tabs">';
    $variables['primary']['#suffix'] = '</ul>';
    $output .= drupal_render($variables['primary']);
  }

  if (!empty($variables['secondary'])) {
    $variables['secondary']['#prefix'] = '<div class="element-invisible">' . t('Secondary tabs') . '</div>';
    $variables['secondary']['#prefix'] .= '<ul class="tabs--secondary nav nav-pills">';
    $variables['secondary']['#suffix'] = '</ul>';
    $output .= drupal_render($variables['secondary']);
  }

  return $output;
}




function strapped_menu_link(array $variables) {
  $element = $variables['element'];
  $sub_menu = '';

  $title = $element['#title'];
  $href = $element['#href'];
  $options = !empty($element['#localized_options']) ? $element['#localized_options'] : array();
  $attributes = !empty($element['#attributes']) ? $element['#attributes'] : array();

  // Wea re adding a span to the title so we always need html.
  $options['html'] = TRUE;

  // @todo either mve this or do it another way?
  if (!$element['#original_link']['expanded'] && (isset($element['#attributes']['class']))) {
    foreach($attributes['class'] as $key => $value) {
      if ($value == 'expanded') {
        unset($attributes['class'][$key]);
      }
    }
  }

  if (isset($element['#below']) && $element['#below']) {
    // Prevent dropdown functions from being added to management menu so it
    // does not affect the navbar module.
    if (($element['#original_link']['menu_name'] == 'management') && (module_exists('navbar'))) {
      $sub_menu = drupal_render($element['#below']);
    }
    elseif ((!empty($element['#original_link']['depth']))) {
      // Add our own wrapper.
      unset($element['#below']['#theme_wrappers']);
      $sub_menu = '<ul>' . drupal_render($element['#below']) . '</ul>';

      // Generate as standard dropdown.
      $title .= ' <span class="caret"></span>';
      $attributes['class'][] = 'dropdown';

    }
  }

  // Filter the title if the "html" is set, otherwise l() will automatically
  // sanitize using check_plain(), so no need to call that here.
  if (!empty($options['html'])) {
    $title = _bootstrap_filter_xss($title);
  }

  // Remove duplciate classes.
  $attributes['class'] = array_unique($attributes['class']);

  return '<li' . drupal_attributes($attributes) . '>' . l('<span>' . $title . '</span>', $href, $options) . $sub_menu . "</li>\n";

}




function strapped_menu_local_action($variables) {
  $link = $variables['element']['#link'];
  $title = $link['title'];
  $icon = _bootstrap_iconize_text($title);
  $href = !empty($link['href']) ? $link['href'] : FALSE;
  $options = isset($link['localized_options']) ? $link['localized_options'] : array();

  // Format the action link.
  if ($href) {
    // Turn link into a mini-button and colorize based on title.
    if ($class = _bootstrap_colorize_text($title)) {
      if (!isset($options['attributes']['class'])) {
        $options['attributes']['class'] = array();
      }
      $string = is_string($options['attributes']['class']);
      if ($string) {
        $options['attributes']['class'] = explode(' ', $options['attributes']['class']);
      }
      $options['attributes']['class'][] = 'btn';
      $options['attributes']['class'][] = 'btn-xs';
      $options['attributes']['class'][] = 'btn-' . $class;
      if ($string) {
        $options['attributes']['class'] = implode(' ', $options['attributes']['class']);
      }
    }
    // Force HTML so we can render any icon that may have been added.
    $options['html'] = !empty($options['html']) || !empty($icon) ? TRUE : FALSE;
  }

  // Filter the title if the "html" is set, otherwise l() will automatically
  // sanitize using check_plain(), so no need to call that here.
  if (!empty($options['html'])) {
    $title = _bootstrap_filter_xss($title);
  }

  return $href ? l($icon . $title, $href, $options) : $icon . $title;
}






